@@ -1003,7 +1003,7 @@ class SelectionExpr(Derived):
         return type(self)(self.source, **self.contents)
 
     def _build_selection_streams(self, source):
-        from holoviews.core.spaces import DynamicMap
+        from holoviews_samap.core.spaces import DynamicMap
         if isinstance(source, DynamicMap):
             element_type = source.type
         else:
@@ -1043,7 +1043,7 @@ class SelectionExpr(Derived):
             # source is None
             return dict(selection_expr=None, bbox=None, region_element=None,)
 
-        from holoviews.core.spaces import DynamicMap
+        from holoviews_samap.core.spaces import DynamicMap
         # Import after checking for hvobj None to avoid "sys.meta_path is None"
         # error on shutdown
         if isinstance(hvobj, DynamicMap):
