@@ -8,9 +8,9 @@ import logging
 
 import numpy as np
 
-from holoviews.core.data import Dataset, MultiInterface
-from holoviews.element import Path, Points, Polygons
-from holoviews.element.comparison import ComparisonTestCase
+from holoviews_samap.core.data import Dataset, MultiInterface
+from holoviews_samap.element import Path, Points, Polygons
+from holoviews_samap.element.comparison import ComparisonTestCase
 from param import get_logger
 
 try:
