@@ -11,10 +11,10 @@ try:
 except:
     raise SkipTest("Could not import xarray, skipping XArrayInterface tests.")
 
-from holoviews.core.data import Dataset, concat
-from holoviews.core.dimension import Dimension
-from holoviews.core.spaces import HoloMap
-from holoviews.element import Image, RGB, HSV, QuadMesh
+from holoviews_samap.core.data import Dataset, concat
+from holoviews_samap.core.dimension import Dimension
+from holoviews_samap.core.spaces import HoloMap
+from holoviews_samap.element import Image, RGB, HSV, QuadMesh
 
 from .test_imageinterface import (
     BaseImageElementInterfaceTests, BaseRGBElementInterfaceTests,
