@@ -3,8 +3,8 @@ Test cases for the composite types built with + and *, i.e. Layout
 and Overlay (does *not* test HoloMaps).
 """
 
-from holoviews import Element, Layout, Overlay, HoloMap
-from holoviews.element.comparison import ComparisonTestCase
+from holoviews_samap import Element, Layout, Overlay, HoloMap
+from holoviews_samap.element.comparison import ComparisonTestCase
 
 
 class ElementTestCase(ComparisonTestCase):
