@@ -6,15 +6,15 @@ from unittest import SkipTest
 
 import param
 import numpy as np
-from holoviews import Dimension, NdLayout, GridSpace, Layout, NdOverlay
-from holoviews.core.spaces import DynamicMap, HoloMap, Callable
-from holoviews.core.options import Store
-from holoviews.element import Image, Scatter, Curve, Text, Points
-from holoviews.operation import histogram
-from holoviews.plotting.util import initialize_dynamic
-from holoviews.streams import Stream, LinkedStream, PointerXY, PointerX, PointerY, RangeX, Buffer, pointer_types
-from holoviews.util import Dynamic
-from holoviews.element.comparison import ComparisonTestCase
+from holoviews_samap import Dimension, NdLayout, GridSpace, Layout, NdOverlay
+from holoviews_samap.core.spaces import DynamicMap, HoloMap, Callable
+from holoviews_samap.core.options import Store
+from holoviews_samap.element import Image, Scatter, Curve, Text, Points
+from holoviews_samap.operation import histogram
+from holoviews_samap.plotting.util import initialize_dynamic
+from holoviews_samap.streams import Stream, LinkedStream, PointerXY, PointerX, PointerY, RangeX, Buffer, pointer_types
+from holoviews_samap.util import Dynamic
+from holoviews_samap.element.comparison import ComparisonTestCase
 
 from ..utils import LoggingComparisonTestCase
 from .test_dimensioned import CustomBackendTestCase, ExampleElement
