@@ -6,30 +6,30 @@ from unittest import SkipTest
 import numpy as np
 import pytest
 
-from holoviews import Store, Histogram, Image, Curve, Points, DynamicMap, opts
-from holoviews.core.options import (
+from holoviews_samap import Store, Histogram, Image, Curve, Points, DynamicMap, opts
+from holoviews_samap.core.options import (
     OptionError, Cycle, Options, OptionTree, StoreOptions, options_policy
 )
-from holoviews.element.comparison import ComparisonTestCase
-from holoviews import plotting              # noqa Register backends
+from holoviews_samap.element.comparison import ComparisonTestCase
+from holoviews_samap import plotting              # noqa Register backends
 
 Options.skip_invalid = False
 
 try:
     # Needed a backend to register backend and options
-    from holoviews.plotting import mpl # noqa
+    from holoviews_samap.plotting import mpl # noqa
 except:
     pass
 
 try:
     # Needed to register backend  and options
-    from holoviews.plotting import bokeh # noqa
+    from holoviews_samap.plotting import bokeh # noqa
 except:
     pass
 
 try:
     # Needed to register backend  and options
-    from holoviews.plotting import plotly # noqa
+    from holoviews_samap.plotting import plotly # noqa
 except:
     pass
 
@@ -967,17 +967,17 @@ class TestLookupOptions(ComparisonTestCase):
         points = Points([[1, 2], [3, 4]])
 
         try:
-            import holoviews.plotting.matplotlib # noqa
+            import holoviews_samap.plotting.matplotlib # noqa
         except:
             pass
 
         try:
-            import holoviews.plotting.bokeh # noqa
+            import holoviews_samap.plotting.bokeh # noqa
         except:
             pass
 
         try:
-            import holoviews.plotting.plotly # noqa
+            import holoviews_samap.plotting.plotly # noqa
         except:
             pass
 
