@@ -16,15 +16,15 @@ try:
 except:
     pd = None
 
-from holoviews.core.util import (
+from holoviews_samap.core.util import (
     sanitize_identifier_fn, find_range, max_range, wrap_tuple_streams,
     deephash, merge_dimensions, get_path, make_path_unique, compute_density,
     date_range, dt_to_int, compute_edges, isfinite, cross_index, closest_match,
     dimension_range, tree_attribute
 )
-from holoviews import Dimension, Element
-from holoviews.streams import PointerXY
-from holoviews.element.comparison import ComparisonTestCase
+from holoviews_samap import Dimension, Element
+from holoviews_samap.streams import PointerXY
+from holoviews_samap.element.comparison import ComparisonTestCase
 
 sanitize_identifier = sanitize_identifier_fn.instance()
 
