@@ -1,9 +1,9 @@
 """
 Tests to make sure all components follow the appropriate API
 """
-from holoviews import element
-from holoviews.element import __all__ as all_elements
-from holoviews.element.comparison import ComparisonTestCase
+from holoviews_samap import element
+from holoviews_samap.element import __all__ as all_elements
+from holoviews_samap.element.comparison import ComparisonTestCase
 
 
 class TestParameterDeclarations(ComparisonTestCase):
