@@ -6,14 +6,14 @@ from unittest import SkipTest, skipIf
 
 import numpy as np
 
-from holoviews.core import NdOverlay
-from holoviews.core.options import Store
-from holoviews.element import (
+from holoviews_samap.core import NdOverlay
+from holoviews_samap.core.options import Store
+from holoviews_samap.element import (
     Area, BoxWhisker, Curve, Distribution, HSpan, Image, Points,
     Rectangles, RGB, Scatter, Segments, Violin, VSpan, Path,
     QuadMesh, Polygons
 )
-from holoviews.element.comparison import ComparisonTestCase
+from holoviews_samap.element.comparison import ComparisonTestCase
 
 try:
     import datashader as ds
@@ -41,7 +41,7 @@ class TestSelection1DExpr(ComparisonTestCase):
 
     def setUp(self):
         try:
-            import holoviews.plotting.bokeh # noqa
+            import holoviews_samap.plotting.bokeh # noqa
         except:
             raise SkipTest("Bokeh selection tests require bokeh.")
         super().setUp()
@@ -223,7 +223,7 @@ class TestSelection2DExpr(ComparisonTestCase):
 
     def setUp(self):
         try:
-            import holoviews.plotting.bokeh # noqa
+            import holoviews_samap.plotting.bokeh # noqa
         except:
             raise SkipTest("Bokeh selection tests require bokeh.")
         super().setUp()
@@ -438,7 +438,7 @@ class TestSelectionGeomExpr(ComparisonTestCase):
 
     def setUp(self):
         try:
-            import holoviews.plotting.bokeh # noqa
+            import holoviews_samap.plotting.bokeh # noqa
         except:
             raise SkipTest("Bokeh selection tests require bokeh.")
         super().setUp()
@@ -545,7 +545,7 @@ class TestSelectionPolyExpr(ComparisonTestCase):
 
     def setUp(self):
         try:
-            import holoviews.plotting.bokeh # noqa
+            import holoviews_samap.plotting.bokeh # noqa
         except:
             raise SkipTest("Bokeh selection tests require bokeh.")
         super().setUp()
