@@ -6,12 +6,12 @@ from unittest import SkipTest
 import numpy as np
 import pyviz_comms as comms
 
-from holoviews.core import DynamicMap
-from holoviews.core.options import Store
-from holoviews.core.util import pd
-from holoviews.element import Points, Polygons, Box, Curve, Table, Rectangles
-from holoviews.element.comparison import ComparisonTestCase
-from holoviews.streams import (
+from holoviews_samap.core import DynamicMap
+from holoviews_samap.core.options import Store
+from holoviews_samap.core.util import pd
+from holoviews_samap.element import Points, Polygons, Box, Curve, Table, Rectangles
+from holoviews_samap.element.comparison import ComparisonTestCase
+from holoviews_samap.streams import (
     PointDraw, PolyDraw, PolyEdit, BoxEdit, PointerXY, PointerX,
     PlotReset, Selection1D, RangeXY, PlotSize, CDSStream, SingleTap
 )
@@ -20,11 +20,11 @@ try:
     from bokeh.events import Tap
     from bokeh.io.doc import set_curdoc
     from bokeh.models import Range1d, Plot, ColumnDataSource, Selection, PolyEditTool
-    from holoviews.plotting.bokeh.callbacks import (
+    from holoviews_samap.plotting.bokeh.callbacks import (
         Callback, PointDrawCallback, PolyDrawCallback, PolyEditCallback,
         BoxEditCallback, PointerXCallback, TapCallback
     )
-    from holoviews.plotting.bokeh.renderer import BokehRenderer
+    from holoviews_samap.plotting.bokeh.renderer import BokehRenderer
     bokeh_server_renderer = BokehRenderer.instance(mode='server')
     bokeh_renderer = BokehRenderer.instance()
 except:
