@@ -1,4 +1,4 @@
-from holoviews.element import Div
+from holoviews_samap.element import Div
 
 from .test_plot import TestBokehPlot, bokeh_renderer
 
