@@ -3,12 +3,12 @@ import re
 
 import numpy as np
 
-from holoviews.core import (HoloMap, GridSpace, Layout, Empty, Dataset,
+from holoviews_samap.core import (HoloMap, GridSpace, Layout, Empty, Dataset,
                             NdOverlay, NdLayout, DynamicMap, Dimension)
-from holoviews.element import Curve, Image, Points, Histogram, Scatter
-from holoviews.streams import Stream
-from holoviews.util import render, opts
-from holoviews.util.transform import dim
+from holoviews_samap.element import Curve, Image, Points, Histogram, Scatter
+from holoviews_samap.streams import Stream
+from holoviews_samap.util import render, opts
+from holoviews_samap.util.transform import dim
 
 try:
     from bokeh.layouts import Column, Row
