@@ -2,11 +2,11 @@ import datetime as dt
 
 import numpy as np
 
-from holoviews.core import NdOverlay, HoloMap
-from holoviews.core.options import Cycle
-from holoviews.element import Path, Polygons, Contours
-from holoviews.streams import PolyDraw
-from holoviews.util.transform import dim
+from holoviews_samap.core import NdOverlay, HoloMap
+from holoviews_samap.core.options import Cycle
+from holoviews_samap.element import Path, Polygons, Contours
+from holoviews_samap.streams import PolyDraw
+from holoviews_samap.util.transform import dim
 
 from .test_plot import TestBokehPlot, bokeh_renderer
 
