@@ -1,6 +1,6 @@
 import numpy as np
 
-from holoviews.element import BoxWhisker
+from holoviews_samap.element import BoxWhisker
 
 from .test_plot import TestMPLPlot, mpl_renderer
 
