@@ -1,6 +1,6 @@
 import numpy as np
 
-from holoviews.element import HexTiles
+from holoviews_samap.element import HexTiles
 
 
 from .test_plot import TestMPLPlot, mpl_renderer
@@ -13,7 +13,7 @@ class TestHexTilesPlot(TestMPLPlot):
         mpl_renderer.get_plot(tiles)
 
     def test_hex_tiles_opts(self):
-        from holoviews.plotting.util import process_cmap
+        from holoviews_samap.plotting.util import process_cmap
         tiles = HexTiles([(0, 0), (0.5, 0.5), (-0.5, -0.5), (-0.4, -0.4)])
         plot = mpl_renderer.get_plot(tiles)
         args, style, _ = plot.get_data(tiles, {}, {})
