@@ -1,4 +1,4 @@
-from holoviews.element import Distribution
+from holoviews_samap.element import Distribution
 
 from .test_plot import TestPlotlyPlot
 
