@@ -1,6 +1,6 @@
 import numpy as np
 
-from holoviews.element import Curve, Image
+from holoviews_samap.element import Curve, Image
 
 from .test_plot import TestPlotlyPlot, plotly_renderer
 
