@@ -2,22 +2,22 @@ from unittest import SkipTest
 
 import numpy as np
 
-from holoviews import NdOverlay, Overlay, Dimension
-from holoviews.core.spaces import DynamicMap, HoloMap
-from holoviews.core.options import Store, Cycle
-from holoviews.element.comparison import ComparisonTestCase
-from holoviews.element import (Image, Scatter, Curve, Points,
+from holoviews_samap import NdOverlay, Overlay, Dimension
+from holoviews_samap.core.spaces import DynamicMap, HoloMap
+from holoviews_samap.core.options import Store, Cycle
+from holoviews_samap.element.comparison import ComparisonTestCase
+from holoviews_samap.element import (Image, Scatter, Curve, Points,
                                Area, VectorField, HLine, Path)
-from holoviews.operation import operation
-from holoviews.plotting.util import (
+from holoviews_samap.operation import operation
+from holoviews_samap.plotting.util import (
     compute_overlayable_zorders, get_min_distance, process_cmap,
     initialize_dynamic, split_dmap_overlay, _get_min_distance_numpy,
     bokeh_palette_to_palette, mplcmap_to_palette, color_intervals,
     get_range, get_axis_padding)
-from holoviews.streams import PointerX
+from holoviews_samap.streams import PointerX
 
 try:
-    from holoviews.plotting.bokeh import util
+    from holoviews_samap.plotting.bokeh import util
     bokeh_renderer = Store.renderers['bokeh']
 except:
     bokeh_renderer = None
@@ -466,7 +466,7 @@ class TestMPLColormapUtils(ComparisonTestCase):
     def setUp(self):
         try:
             import matplotlib.cm # noqa
-            import holoviews.plotting.mpl # noqa
+            import holoviews_samap.plotting.mpl # noqa
         except:
             raise SkipTest("Matplotlib needed to test matplotlib colormap instances")
 
@@ -526,7 +526,7 @@ class TestBokehPaletteUtils(ComparisonTestCase):
     def setUp(self):
         try:
             import bokeh.palettes # noqa
-            import holoviews.plotting.bokeh # noqa
+            import holoviews_samap.plotting.bokeh # noqa
         except:
             raise SkipTest('Bokeh required to test bokeh palette utilities')
 
