@@ -2,8 +2,8 @@
 """
 Test cases for rendering exporters
 """
-from holoviews.element.comparison import ComparisonTestCase
-from holoviews.plotting import Renderer
+from holoviews_samap.element.comparison import ComparisonTestCase
+from holoviews_samap.plotting import Renderer
 
 
 class TestRenderer(ComparisonTestCase):
