@@ -1,17 +1,17 @@
 from unittest import SkipTest, skip, skipIf
 
-import holoviews as hv
+import holoviews_samap as hv
 import pandas as pd
 
-from holoviews.core.options import Cycle, Store
-from holoviews.element import ErrorBars, Points, Rectangles, Table, VSpan
-from holoviews.plotting.util import linear_gradient
-from holoviews.selection import link_selections
-from holoviews.streams import SelectionXY
-from holoviews.element.comparison import ComparisonTestCase
+from holoviews_samap.core.options import Cycle, Store
+from holoviews_samap.element import ErrorBars, Points, Rectangles, Table, VSpan
+from holoviews_samap.plotting.util import linear_gradient
+from holoviews_samap.selection import link_selections
+from holoviews_samap.streams import SelectionXY
+from holoviews_samap.element.comparison import ComparisonTestCase
 
 try:
-    from holoviews.operation.datashader import datashade, dynspread
+    from holoviews_samap.operation.datashader import datashade, dynspread
 except:
     datashade = None
 
@@ -703,7 +703,7 @@ class TestLinkSelectionsPlotly(TestLinkSelections):
 
     def setUp(self):
         try:
-            import holoviews.plotting.plotly # noqa
+            import holoviews_samap.plotting.plotly # noqa
         except:
             raise SkipTest("Plotly selection tests require plotly.")
         super().setUp()
@@ -734,7 +734,7 @@ class TestLinkSelectionsBokeh(TestLinkSelections):
 
     def setUp(self):
         try:
-            import holoviews.plotting.bokeh # noqa
+            import holoviews_samap.plotting.bokeh # noqa
         except:
             raise SkipTest("Bokeh selection tests require bokeh.")
         super().setUp()
