@@ -27,7 +27,7 @@ Store.output_settings = OutputSettings
 
 
 
-def examples(path='holoviews-examples', verbose=False, force=False, root=__file__):
+def examples(path='holoviews_samap-examples', verbose=False, force=False, root=__file__):
     """
     Copies the notebooks to the supplied path.
     """
@@ -310,7 +310,7 @@ class opts(param.ParameterizedFunction):
             raise ValueError("No plotting extension is currently loaded. "
                              "Ensure you load an plotting extension with "
                              "hv.extension or import it explicitly from "
-                             "holoviews.plotting before applying any "
+                             "holoviews_samap.plotting before applying any "
                              "options.")
         elif current_backend not in Store.renderers:
             raise ValueError("Currently selected plotting extension {ext} "
@@ -635,7 +635,7 @@ def renderer(name):
 
 class extension(_pyviz_extension):
     """
-    Helper utility used to load holoviews extensions. These can be
+    Helper utility used to load holoviews_samap extensions. These can be
     plotting extensions, element extensions or anything else that can be
     registered to work with HoloViews.
     """
@@ -670,7 +670,7 @@ class extension(_pyviz_extension):
                 self.param.warning("%s could not be imported, ensure %s is installed."
                              % (backend, backend))
             try:
-                __import__('holoviews.plotting.%s' % imp)
+                __import__('holoviews_samap.plotting.%s' % imp)
                 if selected_backend is None:
                     selected_backend = backend
             except util.VersionError as e:
