@@ -278,7 +278,7 @@ class OutputSettings(KeywordSettings):
             raise ValueError("No plotting extension is currently loaded. "
                              "Ensure you load an plotting extension with "
                              "hv.extension or import it explicitly from "
-                             "holoviews.plotting before using hv.output.")
+                             "holoviews_samap.plotting before using hv.output.")
 
         # Make backup of previous options
         prev_backend = Store.current_backend
